@@ -24,6 +24,7 @@
  ** Feb 13, 2008 - fix problems with generic_get_detailed_header_info(), gzgeneric_get_detailed_header_info()
  ** May 18, 2009 - Add Ability to extract scan date from CEL file header
  ** May 25, 2010 - Multichannel CELfile support adapted from single channel parser
+ ** Sep 4, 2017 - change gzFile* to gzFile
  **
  *************************************************************/
 #include <R.h>
@@ -102,11 +103,9 @@ static int compare_AWSTRING_Intensity(AWSTRING string){
 
 int multichannel_determine_number_channels(const char *filename){
   
-  int i=0, j=0, k=0;
-  int cur_index;
+  int j=0;
   int returnvalue = 0;
   
-  int fread_err=0;
   
   FILE *infile;
   
@@ -158,21 +157,16 @@ int multichannel_determine_number_channels(const char *filename){
 
 char *multichannel_determine_channel_name(const char *filename, int channelindex){
   
-  int i=0, j=0, k=0;
-  int cur_index;
+  int k=0;
   char *returnvalue = 0;
   
-  int fread_err=0;
-  
   FILE *infile;
   
   generic_file_header my_header;
   generic_data_header my_data_header;
   generic_data_group my_data_group;
   
-  generic_data_set my_data_set;
-
-  uint32_t next_group =1;  
+    uint32_t next_group =1;  
 
 
   if ((infile = fopen(filename, "rb")) == NULL)
@@ -217,10 +211,7 @@ char *multichannel_determine_channel_name(const char *filename, int channelindex
 
 int read_genericcel_file_intensities_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows, int channelindex){
 
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
+  int i=0, k=0;
   
   FILE *infile;
 
@@ -274,11 +265,8 @@ int read_genericcel_file_intensities_multichannel(const char *filename, double *
 
 int read_genericcel_file_stddev_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows, int channelindex){
 
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
-  
+  int i=0, k=0;
+    
   FILE *infile;
 
   generic_file_header my_header;
@@ -338,10 +326,7 @@ int read_genericcel_file_stddev_multichannel(const char *filename, double *inten
 
 int read_genericcel_file_npixels_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows,  int channelindex){
 
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
+  int i=0, k=0;
   
   FILE *infile;
 
@@ -409,14 +394,8 @@ int read_genericcel_file_npixels_multichannel(const char *filename, double *inte
 
 void generic_get_masks_outliers_multichannel(const char *filename, int *nmasks, short **masks_x, short **masks_y, int *noutliers, short **outliers_x, short **outliers_y, int channelindex){
 
-
-
-
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
-  
+  int i=0, k=0;
+    
   FILE *infile;
 
   generic_file_header my_header;
@@ -513,13 +492,12 @@ void generic_get_masks_outliers_multichannel(const char *filename, int *nmasks,
 void generic_apply_masks_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows, int rm_mask, int rm_outliers,  int channelindex){
 
 
-  int i=0, j=0;
+  int i=0;
   int cur_index;
   
   short cur_x, cur_y;
 
 
-  int fread_err=0;
   int nrows;
   int size;
 
@@ -613,7 +591,7 @@ void generic_apply_masks_multichannel(const char *filename, double *intensity, i
 
 int isgzGenericMultiChannelCelFile(const char *filename){
 
-  gzFile *infile;
+  gzFile infile;
   generic_file_header file_header;
   generic_data_header data_header;
   
@@ -657,13 +635,11 @@ int isgzGenericMultiChannelCelFile(const char *filename){
 
 int gzmultichannel_determine_number_channels(const char *filename){
   
-  int i=0, j=0, k=0;
-  int cur_index;
+  int j=0;
+ 
   int returnvalue = 0;
-  
-  int fread_err=0;
-  
-  gzFile *infile;
+   
+  gzFile infile;
   
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -710,20 +686,16 @@ int gzmultichannel_determine_number_channels(const char *filename){
 
 char *gzmultichannel_determine_channel_name(const char *filename, int channelindex){
   
-  int i=0, j=0, k=0;
-  int cur_index;
+  int k=0;
+
   char *returnvalue = 0;
   
-  int fread_err=0;
-  
-  gzFile *infile;
+  gzFile infile;
   
   generic_file_header my_header;
   generic_data_header my_data_header;
   generic_data_group my_data_group;
   
-  generic_data_set my_data_set;
-
   uint32_t next_group =1;  
 
   if ((infile = gzopen(filename, "rb")) == NULL)
@@ -760,12 +732,9 @@ char *gzmultichannel_determine_channel_name(const char *filename, int channelind
 
 int gzread_genericcel_file_intensities_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows, int channelindex){
 
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
-  
-  gzFile *infile;
+  int i=0, k=0;
+    
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -816,12 +785,9 @@ int gzread_genericcel_file_intensities_multichannel(const char *filename, double
 
 int gzread_genericcel_file_stddev_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows,  int channelindex){
 
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
-  
-  gzFile *infile;
+  int i=0, k=0;
+    
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -878,12 +844,9 @@ int gzread_genericcel_file_stddev_multichannel(const char *filename, double *int
 
 int gzread_genericcel_file_npixels_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows,  int channelindex){
 
-  int i=0, j=0, k=0;
-  int cur_index;
+  int i=0, k=0;
   
-  int fread_err=0;
-  
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -945,14 +908,9 @@ int gzread_genericcel_file_npixels_multichannel(const char *filename, double *in
 
 void gzgeneric_get_masks_outliers_multichannel(const char *filename, int *nmasks, short **masks_x, short **masks_y, int *noutliers, short **outliers_x, short **outliers_y,  int channelindex){
 
-
-
-  int i=0, j=0, k=0;
-  int cur_index;
-  
-  int fread_err=0;
-  
-  gzFile *infile;
+  int i=0, k=0;
+    
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -1046,17 +1004,15 @@ void gzgeneric_get_masks_outliers_multichannel(const char *filename, int *nmasks
 void gzgeneric_apply_masks_multichannel(const char *filename, double *intensity, int chip_num, int rows, int cols,int chip_dim_rows, int rm_mask, int rm_outliers,  int channelindex){
 
 
-  int i=0, j=0;
+  int i=0;
   int cur_index;
   
   short cur_x, cur_y;
 
-
-  int fread_err=0;
   int nrows;
   int size;
 
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
